kernel for
pathway hsa04020.An object of class lkmt containing exemplary test results for an
application of the logistic kernel machine test, derived from the example data.
data(lkmt.net.kernel.hsa04020)An object of class lkmt for the network-based
kernel and the pathway hsa04020.
gives a formular defining the nullmodel used in the logistic kernel machine test
gives the GWASdata object including the study data
considered in testing
gives the value of the test statistic
specifies the degrees of freedom
includes teh p-value resulting from the test